***********************************************
:py:mod:`gruvi.util` -- Miscellaneous utilities
***********************************************

The :py:mod:`gruvi.util` module contains some miscellaneous utility functions.

.. automodule:: gruvi.util
   :members:
